#!/usr/bin/env python3

__all__ = ['main']

import os
import sys

def main(argv=None):
    import argparse
    if argv is None:
        argv = sys.argv[1:]
    parser = argparse.ArgumentParser('what')
    parser.add_argument('keys')
    parser.add_argument('-k', '--keysep', default=',')
    parser.add_argument('-n', '--num', type=int, default=1)
    args = parser.parse_args(argv)

    if os.path.exists(args.keys):
        keys = open(args.keys).read().splitlines()
    else:
        keys = [a.strip() for a in args.keys.split(args.keysep)]

    import embd
    import wnix
    space = embd.Space()
    shape = space.embed.shape()

    # receive a tensor across a pipe! 🎉
    Q = embd.stdin_to_tensor().reshape((-1, shape))
    output = wnix.Grep(Q, keys).fmt_what(n=args.num)
    print(output)

if __name__ == '__main__':
    main(sys.argv[1:])



#!/usr/bin/env python3

__all__ = ['main']

import os
import re
import sys
import argparse
import subprocess

def run(cmd, input):
    p = subprocess.Popen(cmd, shell=True, stdin=subprocess.PIPE, stdout=subprocess.PIPE)
    input = input.encode() if isinstance(input, str) else input
    stdout, stderr = p.communicate(input)
    return stdout.decode()

def main(argv=None):
    if argv is None:
        argv = sys.argv[1:]
    parser = argparse.ArgumentParser('sort2')
    parser.add_argument('key')
    parser.add_argument('-c', '--cmd', type=str, default=None)
    parser.add_argument('-p', '--paths', action='store_true', help="Interpret inputs as paths")
    parser.add_argument('-i', '--input', action='store_true', help="Short for '-p -c input'")
    parser.add_argument('-d', '--debug', action='store_true')
    args = parser.parse_args(argv)

    if args.input:
        args.cmd = 'input'
        args.paths = True

    from embd import List, Dict

    lines = sys.stdin.read().splitlines()

    q = {l: l for l in lines}

    if args.paths:
        q = {k: open(v, 'rb').read() for k,v in q.items()}

    if args.cmd:
        q = {k: run(args.cmd, v) for k,v in q.items()}

    q = Dict(q)
    k = List([args.key])
    s = q @ k
    if args.debug:
        print(f'=== q ===')
        import json
        print(json.dumps(q.o, indent=2))
        print(q)
        print(f'=== k ===')
        print(k)
        print(f'=== s ===')
        print(s)
        sys.exit(0)

    o = s[args.key].sort_values(ascending=False).index.tolist()
    for l in o:
        print(l)

if __name__ == '__main__':
    main(sys.argv[1:])
